# Introduction
Lunchbox is a library of various tools for common python tasks.

See [documentation](https://theNewFlesh.github.io/lunchbox/) for details.

# Installation
### Python
`pip install lunchbox`

### Docker
1. Install [docker-desktop](https://docs.docker.com/desktop/)
2. `docker pull thenewflesh/lunchbox:latest`

### Docker For Developers
1. Install [docker-desktop](https://docs.docker.com/desktop/)
2. Ensure docker-desktop has at least 4 GB of memory allocated to it.
4. `git clone git@github.com:theNewFlesh/lunchbox.git`
5. `cd lunchbox`
6. `chmod +x bin/lunchbox`
7. `bin/lunchbox start`

The service should take a few minutes to start up.

Run `bin/lunchbox --help` for more help on the command line tool.
